| Title: | R Templates for Reproducible Data Analyses |
|---|---|
| Description: | A collection of R Markdown templates for nicely structured, reproducible data analyses in R. The templates have embedded examples on how to write citations, footnotes, equations and use colored message/info boxes, how to cross-reference different parts/sections in the report, provide a nice table of contents (toc) with a References section and proper R session information as well as examples using DT tables and ggplot2 graphs. The bookdown Lite template theme supports code folding. |
| Authors: | John Zobolas [aut, cph, cre] (ORCID: <https://orcid.org/0000-0002-3609-8674>) |
| Maintainer: | John Zobolas <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.8.0 |
| Built: | 2026-05-15 05:51:54 UTC |
| Source: | https://github.com/bblodfon/rtemps |
This function creates a new directory under the current directory, which will contain the given files of the specified template, ready to be rendered.
create_rtemp(dirname = "new-dir", template = "united_html")create_rtemp(dirname = "new-dir", template = "united_html")
dirname |
name of the directory to create. If not specified, a directory new-dir will be created. |
template |
which template to use? |
The available templates are: united_html (default), bookdown_lite.
The name of the main .Rmd file will be index.Rmd.
## Not run: create_rtemp(dirname = "tmp_dir", template = "united_html") ## End(Not run)## Not run: create_rtemp(dirname = "tmp_dir", template = "united_html") ## End(Not run)