Welcome to ClientVPS Mirrors

Help for package rtemps
Type: Package
Title: R Templates for Reproducible Data Analyses
Version: 0.8.0
Description: A collection of R Markdown templates for nicely structured, reproducible data analyses in R. The templates have embedded examples on how to write citations, footnotes, equations and use colored message/info boxes, how to cross-reference different parts/sections in the report, provide a nice table of contents (toc) with a References section and proper R session information as well as examples using DT tables and ggplot2 graphs. The bookdown Lite template theme supports code folding.
License: MIT + file LICENSE
URL: https://github.com/bblodfon/rtemps
Encoding: UTF-8
LazyData: true
RoxygenNote: 7.0.2
Imports: knitr, rmarkdown, bookdown, DT, ggplot2, xfun
NeedsCompilation: no
Packaged: 2020-11-04 21:06:58 UTC; john
Author: John Zobolas ORCID iD [aut, cph, cre]
Maintainer: John Zobolas <bblodfon@gmail.com>
Repository: CRAN
Date/Publication: 2020-11-04 21:40:03 UTC

Create a new directory with the specified R template

Description

This function creates a new directory under the current directory, which will contain the given files of the specified template, ready to be rendered.

Usage

create_rtemp(dirname = "new-dir", template = "united_html")

Arguments

dirname

name of the directory to create. If not specified, a directory new-dir will be created.

template

which template to use?

Details

The available templates are: united_html (default), bookdown_lite. The name of the main .Rmd file will be index.Rmd.

Examples

## Not run: 
create_rtemp(dirname = "tmp_dir", template = "united_html")

## End(Not run)

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.